@@ -1,7 +1,7 @@
 use strict;
 package Dist::Zilla::PluginBundle::Author::MAXHQ;
 # ABSTRACT: MAXHQ's default Dist::Zilla configuration
-$Dist::Zilla::PluginBundle::Author::MAXHQ::VERSION = '2.001000';
+$Dist::Zilla::PluginBundle::Author::MAXHQ::VERSION = '2.002000';
 #pod =encoding UTF-8
 #pod
 #pod =head1 SYNOPSIS
@@ -113,6 +113,8 @@ $Dist::Zilla::PluginBundle::Author::MAXHQ::VERSION = '2.001000';
 #pod 	[Test::Perl::Critic]
 #pod 	[PodCoverageTests]
 #pod 	[PodSyntaxTests]
+#pod 	[Test::Pod::No404s]
+#pod 	[Test::Pod::LinkCheck]
 #pod
 #pod 	#
 #pod 	# Auto generation --- docs
@@ -301,6 +303,8 @@ sub configure {
 		'Test::Perl::Critic',
 		'PodCoverageTests',
 		'PodSyntaxTests',
+		'Test::Pod::No404s',
+		'Test::Pod::LinkCheck',
 
 		#
 		# Auto generation --- docs
@@ -334,7 +338,7 @@ __PACKAGE__->meta->make_immutable;
 {
 	package Dist::Zilla::Plugin::ShareDir::ProjectDistDir;
 	# ABSTRACT: install a directory's contents as "ShareDir" content
-$Dist::Zilla::Plugin::ShareDir::ProjectDistDir::VERSION = '2.001000';
+$Dist::Zilla::Plugin::ShareDir::ProjectDistDir::VERSION = '2.002000';
 use Moose;
 	use namespace::autoclean;
 
@@ -382,7 +386,7 @@ Dist::Zilla::PluginBundle::Author::MAXHQ - MAXHQ's default Dist::Zilla configura
 
 =head1 VERSION
 
-version 2.001000
+version 2.002000
 
 =head1 SYNOPSIS
 
@@ -499,6 +503,8 @@ Currently this plugin bundle is equivalent to:
 	[Test::Perl::Critic]
 	[PodCoverageTests]
 	[PodSyntaxTests]
+	[Test::Pod::No404s]
+	[Test::Pod::LinkCheck]
 
 	#
 	# Auto generation --- docs
